@@ -19,7 +19,61 @@ import pika
 import requests
 
 
-@api.route('/sms', methods=['POST'])
+# Nettoie un texte pour le rendre compatible GSM 7-bit (Ce 15 septembre 2025 par Alain)
+def clean_for_gsm7(text):
+    """
+    Nettoie un texte pour le rendre compatible GSM 7-bit.
+    Remplace les caractères non supportés par des équivalents proches.
+    """
+    replacements = {
+        "’": "'",
+        "‘": "'",
+        "“": '"',
+        "”": '"',
+        "–": "-",
+        "—": "-",
+        "…": "...",
+        "«": '"',
+        "»": '"',
+        "€": "EUR",
+        "£": "GBP",
+        "¥": "JPY",
+        "©": "(c)",
+        "®": "(R)",
+        "™": "(TM)",
+        # Accents français courants → version non accentuée
+        "é": "e",
+        "è": "e",
+        "ê": "e",
+        "ë": "e",
+        "à": "a",
+        "â": "a",
+        "ä": "a",
+        "ù": "u",
+        "û": "u",
+        "ü": "u",
+        "î": "i",
+        "ï": "i",
+        "ô": "o",
+        "ö": "o",
+        "ç": "c",
+        "É": "E",
+        "È": "E",
+        "Ç": "C",
+        # Ajoute d'autres si nécessaire
+    }
+
+    for old, new in replacements.items():
+        text = text.replace(old, new)
+
+    # Normalisation Unicode
+    text = unicodedata.normalize("NFKD", text)
+    # Garder uniquement les caractères ASCII
+    text = "".join(c for c in text if ord(c) < 128)
+    return text
+
+
+@api.route("/sms", methods=["POST"])
 def send_sms():
     """
     Envoi de SMS.
@@ -83,125 +137,131 @@ def send_sms():
     json_doc = request.get_json() or {}
 
     LOGS.logger.info(
-        "Incoming SMS: Parameters={} headers={} json={}"
-        .format(params, headers, json_doc)
+        "Incoming SMS: Parameters={} headers={} json={}".format(
+            params, headers, json_doc
+        )
     )
     msisdn_sender_id_list = []
     msisdn_telma_l = []
-    smpp = json_doc.get('sender_id')
+    smpp = json_doc.get("sender_id")
 
-    if ',' in json_doc["msisdn"]:
-        msisdns = json_doc["msisdn"].replace(' ', '')
-        msisdns = msisdns.split(',')
+    if "," in json_doc["msisdn"]:
+        msisdns = json_doc["msisdn"].replace(" ", "")
+        msisdns = msisdns.split(",")
 
         for msisdn in msisdns:
             sender_id = define_sender_id(msisdn, smpp, user)
-            LOGS.logger.info('[{} sent to smpp {}]'.format(msisdn, sender_id))
+            LOGS.logger.info("[{} sent to smpp {}]".format(msisdn, sender_id))
             if sender_id == "orange":
                 msisdn_telma_l.append(msisdn)
             else:
                 msisdn_sender_id_list.append((msisdn, sender_id))
     else:
         sender_id = define_sender_id(json_doc["msisdn"], smpp, user)
-        LOGS.logger.info(
-            '[{} sent to smpp {}'.format(json_doc["msisdn"], sender_id))
+        LOGS.logger.info("[{} sent to smpp {}".format(json_doc["msisdn"], sender_id))
         if sender_id == "orange":
             msisdn_telma_l.append(json_doc["msisdn"])
         else:
             msisdn_sender_id_list.append((json_doc["msisdn"], sender_id))
 
     if msisdn_telma_l:
+        # Nettoyage du message pour GSM 7-bit
+        original_message = json_doc["message"]
+        cleaned_message = clean_for_gsm7(original_message)
+        if cleaned_message != original_message:
+            LOGS.logger.warning(
+                "Message cleaned for GSM 7-bit: '{}' -> '{}'".format(
+                    original_message, cleaned_message
+                )
+            )
+
+        json_doc["message"] = cleaned_message
+
         for msisdn in msisdn_telma_l:
             try:
                 requests.post(
-                    "http://bldv035v.malagasy.com:11223/simbank",
+                    "http://192.168.77.24:11223/simbank",
                     params={
-                        'phonenumber': msisdn,
-                        'message': json_doc["message"],
-                    }
+                        "phonenumber": msisdn,
+                        "message": json_doc["message"],
+                        "additional_info": smpp,
+                    },
+                )
+                LOGS.logger.info(
+                    "message: {}, msisdn: {} sent to simbank "
+                    "service zato ".format(
+                        json_doc["message"],
+                        msisdn,
+                        smpp,
+                    )
                 )
-                LOGS.logger.info('message: {}, msisdn: {} sent to simbank '
-                                 'service zato '.format(
-                                    json_doc["message"],
-                                    msisdn
-                                 ))
 
             except Exception as e:
-                LOGS.logger.info('Failed sent message: {}, msisdn: {} '
-                                 'to simbank service zato, reason: {}'.format(
-                                    json_doc["message"],
-                                    msisdn,
-                                    e
-                                 ))
+                LOGS.logger.info(
+                    "Failed sent message: {}, msisdn: {} "
+                    "to simbank service zato, reason: {}".format(
+                        json_doc["message"], msisdn, e
+                    )
+                )
 
     for msisdn, sender_id in msisdn_sender_id_list:
         try:
-            json_doc['sender_id'] = sender_id
-            json_doc['msisdn'] = msisdn
-            queue = CONFIG[sender_id]['account']
+            json_doc["sender_id"] = sender_id
+            json_doc["msisdn"] = msisdn
+            queue = CONFIG[sender_id]["account"]
         except KeyError:
             return bad_request(
                 message="Le sender_id n'exist pas",
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
-                )
+                code="{}-{}".format(SERVICE_CODE, "4001"),
+                service_code=SERVICE_CODE,
+            )
 
         document = {
-            'auth': auth or (),
-            'params': params,
-            'headers': headers,
-            'json': json_doc
-            }
+            "auth": auth or (),
+            "params": params,
+            "headers": headers,
+            "json": json_doc,
+        }
 
         try:
             connection = pika.BlockingConnection(
-                pika.ConnectionParameters(
-                    host='localhost',
-                    virtual_host='/smsc'
-                    )
-                )
-            LOGS.logger.info('[{}] Connection '
-                             'to Pika established'.format(document))
+                pika.ConnectionParameters(host="localhost", virtual_host="/smsc")
+            )
+            LOGS.logger.info("[{}] Connection " "to Pika established".format(document))
         except Exception:
             # exception de connection lancée par pika
             # il faut que rabbitmq-server soit installé
             # et que le vhost /{service} existe déjà
             return internal_error(
                 message="serveur RabbitMQ injoignable",
-                code='{}-5000'.format(SERVICE_CODE),
-                service_code=SERVICE_CODE
-                )
+                code="{}-5000".format(SERVICE_CODE),
+                service_code=SERVICE_CODE,
+            )
         else:
             # decodage du message
-            msg_doc = document['json']['message']
+            msg_doc = document["json"]["message"]
             z = msg_doc.replace("’", "'")
             z = msg_doc.replace("`", "'")
-            msg_doc = unicodedata.normalize('NFKD', z)
-            msg_doc = msg_doc.encode('ascii', 'ignore')
+            msg_doc = unicodedata.normalize("NFKD", z)
+            msg_doc = msg_doc.encode("ascii", "ignore")
             msg_doc = msg_doc.decode()
-            document['json']['message'] = msg_doc
+            document["json"]["message"] = msg_doc
             journal.send("____MESSAGE____ : `{}`".format(msg_doc))
             #
             channel = connection.channel()
-            channel.exchange_declare(
-                exchange='sendsms',
-                exchange_type='topic'
-                )
+            channel.exchange_declare(exchange="sendsms", exchange_type="topic")
             # déclaration idempotente: pas grave si l'exchange existe déjà
             channel.basic_publish(
-                exchange='sendsms',
+                exchange="sendsms",
                 routing_key=queue,
                 body=json.dumps(document),
-                properties=pika.BasicProperties(delivery_mode=2)
-                )
+                properties=pika.BasicProperties(delivery_mode=2),
+            )
             connection.close()
     return success(service_code=SERVICE_CODE)
 
 
-@api.route('/sms/<string:uuid>', methods=['GET'])
+@api.route("/sms/<string:uuid>", methods=["GET"])
 def get_sms(uuid):
     """
     Lecture des SMS.
@@ -250,55 +310,40 @@ def get_sms(uuid):
     except ValueError:
         return not_found(
             message="Le compte {} n'existe pas".format(uuid),
-            code='{}-{}'.format(
-                SERVICE_CODE,
-                '4040'
-                ),
-            service_code=SERVICE_CODE
-            )
+            code="{}-{}".format(SERVICE_CODE, "4040"),
+            service_code=SERVICE_CODE,
+        )
     else:
-        start = request.args.get('start', None)
-        stop = request.args.get('stop', None)
-        bool_sms = request.args.get('bool_sms', False)
+        start = request.args.get("start", None)
+        stop = request.args.get("stop", None)
+        bool_sms = request.args.get("bool_sms", False)
         if not start:
             start = datetime.now() - timedelta(30)
         else:
             try:
-                start = datetime.strptime(start, '%d%m%Y %H%M%S')
+                start = datetime.strptime(start, "%d%m%Y %H%M%S")
             except ValueError:
                 return bad_request(
-                    message='Le format de date '
-                    'est ddmmyyyy hhmmss',
-                    code='{}-{}'.format(
-                        SERVICE_CODE,
-                        '4001'
-                        ),
-                    service_code=SERVICE_CODE
-                    )
+                    message="Le format de date " "est ddmmyyyy hhmmss",
+                    code="{}-{}".format(SERVICE_CODE, "4001"),
+                    service_code=SERVICE_CODE,
+                )
         if not stop:
             stop = datetime.now()
         else:
             try:
-                stop = datetime.strptime(stop, '%d%m%Y %H%M%S')
+                stop = datetime.strptime(stop, "%d%m%Y %H%M%S")
             except ValueError:
                 return bad_request(
-                    message='Le format correct de date'
-                    ' est ddmmyyyy hhmmss',
-                    code='{}-{}'.format(
-                        SERVICE_CODE,
-                        '4001'
-                        ),
-                    service_code=SERVICE_CODE
-                    )
-        infos = customer.check_sms(
-            start,
-            stop,
-            bool_sms
-            )
+                    message="Le format correct de date" " est ddmmyyyy hhmmss",
+                    code="{}-{}".format(SERVICE_CODE, "4001"),
+                    service_code=SERVICE_CODE,
+                )
+        infos = customer.check_sms(start, stop, bool_sms)
     return jsonify(infos)
 
 
-@api.route('/sms/delivery', methods=['GET'])
+@api.route("/sms/delivery", methods=["GET"])
 def get_delivery_sms():
     """
     Lecture des SMS.
@@ -343,27 +388,20 @@ def get_delivery_sms():
         description: Erreur de connection au SMSC
     """
     customer = lib_customer.Getsms()
-    msisdn = request.args.get('msisdn', None)
-    request_id = request.args.get('request_id', None)
+    msisdn = request.args.get("msisdn", None)
+    request_id = request.args.get("request_id", None)
     if not request_id:
         return bad_request(
-                  message='Le format request_id '
-                          'est incorrect ',
-                  code='{}-{}'.format(
-                      SERVICE_CODE,
-                      '4001'
-                      ),
-                  service_code=SERVICE_CODE
-                  )
+            message="Le format request_id " "est incorrect ",
+            code="{}-{}".format(SERVICE_CODE, "4001"),
+            service_code=SERVICE_CODE,
+        )
     else:
-        infos = customer.delivery_sms(
-            request_id,
-            msisdn
-            )
+        infos = customer.delivery_sms(request_id, msisdn)
     return jsonify(infos)
 
 
-@api.route('/sms/<string:uuid>', methods=['PUT'])
+@api.route("/sms/<string:uuid>", methods=["PUT"])
 def update_sms(uuid):
     """
     modifier status de SMS.
@@ -396,22 +434,19 @@ def update_sms(uuid):
         description: Erreur de connection au SMSC
     """
     customer = lib_customer.Getsms(uuid)
-    ident = request.args.get('ident', None)
+    ident = request.args.get("ident", None)
     if not ident:
         return bad_request(
-            message='Identifiant obligatoire',
-            code='{}-{}'.format(
-                SERVICE_CODE,
-                '4001'
-                ),
-            service_code=SERVICE_CODE
-            )
+            message="Identifiant obligatoire",
+            code="{}-{}".format(SERVICE_CODE, "4001"),
+            service_code=SERVICE_CODE,
+        )
     else:
         infos = customer.update_sms(ident)
         return jsonify(infos)
 
 
-@api.route('/sms/connect/<string:uuid>', methods=['POST'])
+@api.route("/sms/connect/<string:uuid>", methods=["POST"])
 def connect_sms(uuid):
     """
     Cette ressource ce connecte/deconnecte au SMSC
@@ -443,12 +478,9 @@ def connect_sms(uuid):
     except ValueError:
         return not_found(
             message="Impossible de se reconnecter au SMSC",
-            code='{}-{}'.format(
-                SERVICE_CODE,
-                '4040'
-                ),
-            service_code=SERVICE_CODE
-            )
+            code="{}-{}".format(SERVICE_CODE, "4040"),
+            service_code=SERVICE_CODE,
+        )
     return jsonify(result)
 
 
@@ -461,16 +493,18 @@ def define_sender_id(msisdn, smpp, user):
         sender_id = "orange"
     elif smpp == "mfs":
         sender_id = "mfs"
-    elif not telma and smpp == 'orange':
+    elif not telma and smpp == "orange":
         LOGS.logger.warning(
             "MSISDN '{}' is not Telma but targeting Orange SMPP. "
             "Redirected to default SMPP.".format(msisdn)
         )
         sender_id = "Blueline"
     else:
-        if user.startswith('partenaire'):
-            sender_id = user.split('_')[1]
+        if user.startswith("partenaire"):
+            sender_id = user.split("_")[1]
         else:
-            sender_id = smpp or 'bip'
+            sender_id = smpp or "bip"
     return sender_id
+
+
 # EOF
