@@ -187,10 +187,10 @@ class Getsms(object):
             )
         return url
 
-    def chunks(self, list_l, n):
+    def chunks(self, l, n):
         if n < 1:
             n = 1
-        return [list_l[i:i + n] for i in range(0, len(list_l), n)]
+        return [l[i:i + n] for i in range(0, len(l), n)]
 
     def gsm_decode(self, hexstr):
         hexparts = self.chunks(hexstr, 2)
@@ -399,5 +399,4 @@ class Getsms(object):
             sms['bool_sms'] = str(result.pending)
         return sms
 
-
 # EOF
